<?php

//WordPressセットアップ
//--------------------------------------------------------------------
function rindou_theme_support()
{

    add_theme_support('automatic-feed-links');
    add_theme_support('post-thumbnails');
    set_post_thumbnail_size(1200, 9999);
    add_theme_support('title-tag');
    add_theme_support('custom-logo');
    add_theme_support('editor-styles');
    add_theme_support('custom-header');
    add_theme_support(
        'html5',
        array(
            'search-form',
            'comment-form',
            'comment-list',
            'gallery',
            'caption',
            'script',
            'style',
        )
    );
}
add_action('after_setup_theme', 'rindou_theme_support');


//WordPressテーマカスタマイザー
//--------------------------------------------------------------------
function theme_customize($wp_customize)
{
    // 「ヘッダー画像」を削除	
    $wp_customize->remove_section("header_image");
    // 「色」を削除	
    $wp_customize->remove_section("colors");
    // 「ウィジェット」を削除
    $wp_customize->remove_panel("widgets");
    // 「ホームページ設定」を削除
    $wp_customize->remove_section("static_front_page");


    //ヘッダー・CTAエリア・フッター設定'
    $wp_customize->add_section('header_footer_section', array(
        'title' => 'ヘッダー・CTAエリア・フッター設定',
        'priority' => 60,
        'description' => 'ヘッダー、CTAエリアに表示される電話番号、お問い合わせフォームURL、フッターの住所を設定してください。',
    ));
    //CTAエリアの自由入力欄
    $wp_customize->add_setting('cta_content');
    $wp_customize->add_control(new WP_Customize_Control($wp_customize, 'cta_content_control', array(
        'label' => 'CTAエリアの自由入力欄',
        'section' => 'header_footer_section',
        'settings' => 'cta_content',
        'description' => '連絡先が表示されるCTA(Call To Action)エリアの電話番号上部に表示されます。',
        'type'     => 'textarea',
    )));
    //電話番号
    $wp_customize->add_setting('tel_number');
    $wp_customize->add_control(new WP_Customize_Control($wp_customize, 'tel_control', array(
        'label' => '電話番号',
        'section' => 'header_footer_section',
        'settings' => 'tel_number',
        'description' => '電話番号を設定してください。',
    )));
    //受付時間
    $wp_customize->add_setting('tel_number_time');
    $wp_customize->add_control(new WP_Customize_Control($wp_customize, 'tel_time_control', array(
        'label' => '受付時間',
        'section' => 'header_footer_section',
        'settings' => 'tel_number_time',
        'description' => '電話の受付時間を設定してください。',
    )));
    //お問い合わせURL
    $wp_customize->add_setting('contact_url');
    $wp_customize->add_control(new WP_Customize_Control($wp_customize, 'contact_control', array(
        'label' => 'お問い合わせフォームURL',
        'section' => 'header_footer_section',
        'settings' => 'contact_url',
        'description' => 'お問い合わせフォームURLを設定してください。',
    )));
    //CTA画像背景
    $wp_customize->add_setting('cta_image');
    $wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'cta_control', array(
        'label' => 'CTA背景画像',
        'section' => 'header_footer_section',
        'settings' => 'cta_image',
        'description' => '連絡先が表示されるCTA(Call To Action)エリアの背景画像を設定してください。',
    )));

    //フッター情報
    $wp_customize->add_setting('footer_text');
    $wp_customize->add_control(new WP_Customize_Control($wp_customize, 'footer_control', array(
        'label' => 'フッター情報',
        'section' => 'header_footer_section',
        'settings' => 'footer_text',
        'description' => '事務所の住所などを入れてください。',
        'type'     => 'textarea',
    )));

    //ブログヘッダー画像
    $wp_customize->add_section('blog_section', array(
        'title' => 'ブログヘッダー画像設定',
        'priority' => 70,
        'description' => 'ブログヘッダー画像の設定を行います。',
    ));

    $wp_customize->add_setting('blog_image');
    $wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'blog_control', array(
        'label' => 'ブログヘッダー画像',
        'section' => 'blog_section',
        'settings' => 'blog_image',
        'description' => 'ブログヘッダー画像を設定してください。',
    )));


    //色
    $wp_customize->add_section('theme_color_customize', array(
        'title' => __('色設定', 'color'),
        'priority' => 50,
    ));

    $wp_customize->add_setting('main_color', array('default' => '#DF8601',));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'main_color', array(
        'label' => __('メインカラー', 'color'),
        'section' => 'theme_color_customize',
        'settings' => 'main_color',
    )));

    $wp_customize->add_setting('sub_color', array('default' => '#FDE932',));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'sub_color', array(
        'label' => __('サブカラー', 'color'),
        'section' => 'theme_color_customize',
        'settings' => 'sub_color',
    )));

    $wp_customize->add_setting('bg_color', array('default' => '#f6f6f6',));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'bg_color', array(
        'label' => __('背景色', 'color'),
        'section' => 'theme_color_customize',
        'settings' => 'bg_color',
    )));
}
add_action('customize_register', 'theme_customize');


//ブログヘッダー画像
function get_blog_image_url()
{
    return esc_url(get_theme_mod('blog_image'));
}
//電話番号
function get_tel_number()
{
    return get_theme_mod('tel_number');
}
//受付時間
function get_tel_number_time()
{
    return get_theme_mod('tel_number_time');
}
//お問い合わせURL
function get_contact_url()
{
    return get_theme_mod('contact_url');
}
//フッター情報
function get_footer_text()
{
    return get_theme_mod('footer_text');
}
//CTA背景画像
function get_cta_image()
{
    return esc_url(get_theme_mod('cta_image'));
}
//CTAテキスト
function get_cta_content()
{
    return get_theme_mod('cta_content');
}


//色出力
//--------------------
function theme_customize_css()
{
    $main_color = get_theme_mod('main_color', '#DF8601');
    $sub_color = get_theme_mod('sub_color', '#FDE932');
    $bg_color = get_theme_mod('bg_color', '#f6f6f6');

    $color_hex_main = $main_color;

    $code_red = hexdec(substr($color_hex_main, 1, 2));
    $code_green = hexdec(substr($color_hex_main, 3, 2));
    $code_blue = hexdec(substr($color_hex_main, 5, 2));

    $color_rgb_main = "" . $code_red . ", " . $code_green . ", " . $code_blue . "";

    $color_hex_sub = $sub_color;

    $code_red = hexdec(substr($color_hex_sub, 1, 2));
    $code_green = hexdec(substr($color_hex_sub, 3, 2));
    $code_blue = hexdec(substr($color_hex_sub, 5, 2));

    $color_rgb_sub = "" . $code_red . ", " . $code_green . ", " . $code_blue . "";
?>
    <style type="text/css">
        /*メインカラー*/
        .main-color,
        a,
        .button-common,
        .comment-form input[type="submit"],
        .header-menu li a:hover,
        .blog-content-link:hover,
        .blog-content-link:hover .blog-item-text,
        .blog-cate a:hover,
        .wp-block-group__inner-container>ul>li>a:hover,
        .wp-block-group__inner-container>ol>li>a:hover,
        .widget>ul>li>a:hover,
        .widget>ol>li>a:hover,
        .card-item svg,
        .gyoumu-naiyou .tokuchou-title svg,
        .company-station-title,
        .contact-tel-numuber,
        .wpcf7 input[type="submit"] {
            color: <?php echo $main_color; ?>;
        }

        .button-common,
        .comment-form input[type="submit"],
        .page-numbers span,
        .wpcf7 input[type="submit"],
        .card-item-link:hover,
        .wpcf7 input[type="submit"] {
            border-color: <?php echo $main_color; ?>;
        }

        .button-common:hover,
        .header-mail-link,
        .cta-box,
        .comment-form input[type="submit"]:hover,
        .page-numbers a:hover,
        .page-numbers span,
        .card-item-link:hover,
        .wp-block-search input[type="submit"],
        .wp-block-search button.wp-block-search__button,
        .search-form input[type="submit"],
        .search-form button.wp-block-search__button,
        .home-greeting::after,
        .flow-simple-item::before,
        .flow-detail-title::before,
        .wpcf7 input[type="submit"]:hover {
            background-color: <?php echo $main_color; ?>;
        }

        a:hover {
            color: rgba(<?php echo $color_rgb_main; ?>, .7);
        }

        .wp-block-search input[type="submit"]:hover,
        .wp-block-search button.wp-block-search__button:hover,
        .search-form input[type="submit"]:hover,
        .search-form button.wp-block-search__button:hover,
        .header-mail-link:hover {
            background-color: rgba(<?php echo $color_rgb_main; ?>, .7);
        }

        .drawer-content {
            background-color: rgba(<?php echo $color_rgb_main; ?>, .95);
        }

        /*サブカラー*/
        .sub-color {
            color: <?php echo $sub_color; ?>;
        }

        .header-tel-link,
        .section-title::after,
        .tokuchou-box-image,
        .tokuchou-box::after,
        .flow-faq-inner::before {
            background-color: <?php echo $sub_color; ?>;
        }

        .header-tel-link:hover {
            background-color: rgba(<?php echo $color_rgb_sub; ?>, .7);
        }

        /*背景色*/
        .bg-color,
        .table-common th,
        .table-second thead th,
        .tokuchou-box,
        .company-about .two-column::after {
            background-color: <?php echo $bg_color; ?>;
        }
    </style>
    <?php }
add_action('wp_head', 'theme_customize_css');

//スタイルシート、JS読み込み
//--------------------------------------------------------------------
function rn_scripts()
{
    wp_enqueue_style('rn-css-ress', get_template_directory_uri() . '/assets/css/ress.min.css');
    wp_enqueue_style('rn-css-style', get_template_directory_uri() . '/assets/css/style.css',array(),'1.0.1');
    wp_enqueue_script('jquery');
    wp_enqueue_script('rn-js-fontawesome', get_template_directory_uri() . '/assets/js/all.js', array(), '1.0.1', true);
    wp_enqueue_script('rn-js-style', get_template_directory_uri() . '/assets/js/style.js', array(), '1.0.1', true);


    if (is_singular() && comments_open() && get_option('thread_comments')) {
        wp_enqueue_script('comment-reply');
    }
}
add_action('wp_enqueue_scripts', 'rn_scripts');

add_editor_style(get_template_directory_uri() . '/assets/css/editor-style.css');



//ヘッダーに追記
//--------------------------------------------------------------------
function meta_headcustomtags()
{
    $headcustomtag = <<<EOM

<link rel="preconnect" href="https://fonts.googleapis.com">
<link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
<link href="https://fonts.googleapis.com/css2?family=La+Belle+Aurore&display=swap" rel="stylesheet">

EOM;
    echo $headcustomtag;
}
add_action('wp_head', 'meta_headcustomtags', 99);

//抜粋
//--------------------------------------------------------------------
function rindou_change_excerpt_length($length)
{
    return 80;
}
add_filter('excerpt_length', 'rindou_change_excerpt_length', 999);

function rindou_change_excerpt_more($more)
{
    $html = '&thinsp;...&thinsp;<span class="article-list__text-more">続きを読む</span>';
    return $html;
}

add_filter('excerpt_more', 'rindou_change_excerpt_more');


//カスタムメニュー
//--------------------------------------------------------------------
function rindou_menus()
{

    $locations = array(
        'header-navi'  => __('グローバルメニュー'),
        'footer-navi'   => __('フッターメニュー'),
    );

    register_nav_menus($locations);
}

add_action('init', 'rindou_menus');

// 「メールアドレスが公開されることはありません。 * が付いている欄は必須項目です」の文言を変更
//--------------------------------------------------------------------
add_filter('comment_form_defaults', 'change_comment_email_notes');

function change_comment_email_notes($defaults)
{

    $defaults['comment_notes_before'] = '<p class="comment-notes">メールアドレスが公開されることはありません。</p>';

    return $defaults;
}

//ウィジェット
//--------------------------------------------------------------------
function rindou_sidebar_registration()
{

    $shared_args = array(
        'before_title'  => '<h3 class="widget-ttl">',
        'after_title'   => '</h3>',
        'before_widget' => '<aside class="footer-aside__list widget %2$s">',
        'after_widget'  => '</aside>',
    );

    register_sidebar(
        array_merge(
            $shared_args,
            array(
                'name'        => __('ウィジェット'),
                'id'          => 'sidebar-1',
                'description' => __('記事の下に表示されます。'),
            )
        )
    );
}

add_action('widgets_init', 'rindou_sidebar_registration');


//ウィジェット年別アーカイブ
//--------------------------------------------------------------------
class Widget_Archives2 extends WP_Widget
{

    function __construct()
    {
        $widget_ops = array('classname' => 'widget_archives2', 'description' => 'サイトの投稿の年別/月別アーカイブ');
        parent::__construct('archives2', 'アーカイブ （年別/月別）', $widget_ops);
    }

    function widget($args, $instance)
    {
        extract($args);
        $c = !empty($instance['count']) ? '1' : '0';
        $title = apply_filters('widget_title', empty($instance['title']) ? __('Archives') : $instance['title'], $instance, $this->id_base);

        echo $before_widget;
        if ($title)
            echo $before_title . $title . $after_title;

        $this->get_archives(apply_filters('widget_archives2_args', array('show_post_count' => $c)));

        echo $after_widget;
    }

    function update($new_instance, $old_instance)
    {
        $instance = $old_instance;
        $new_instance = wp_parse_args((array) $new_instance, array('title' => '', 'count' => 0));
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['count'] = $new_instance['count'] ? 1 : 0;

        return $instance;
    }

    function form($instance)
    {
        $instance = wp_parse_args((array) $instance, array('title' => '', 'count' => 0));
        $title = strip_tags($instance['title']);
        $count = $instance['count'] ? 'checked="checked"' : '';
    ?>
        <p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
        </p>
        <p>
            <input class="checkbox" type="checkbox" <?php echo $count; ?> id="<?php echo $this->get_field_id('count'); ?>" name="<?php echo $this->get_field_name('count'); ?>" />
            <label for="<?php echo $this->get_field_id('count'); ?>"><?php _e('Show post counts'); ?></label>
        </p>
<?php
    }

    function get_archives($args = '')
    {

        $defaults = array(
            'limit' => '',
            'before' => '',
            'after' => '',
            'show_post_count' => false,
            'echo' => 1,
            'order' => 'ASC',
        );

        $r = wp_parse_args($args, $defaults);
        extract($r, EXTR_SKIP);

        $arcresults = $this->get_monthly_archives_data($r);

        $output = $this->build_html($r, $arcresults);

        if ($echo)
            echo $output;
        else
            return $output;
    }

    function get_monthly_archives_data($args)
    {
        global $wpdb;
        extract($args, EXTR_SKIP);

        if ('' != $limit) {
            $limit = absint($limit);
            $limit = ' LIMIT ' . $limit;
        }

        $order = strtoupper($order);
        if ($order !== 'ASC')
            $order = 'DESC';

        //filters
        $where = apply_filters('getarchives2_where', "WHERE post_type = 'post' AND post_status = 'publish'", $args);
        $join = apply_filters('getarchives2_join', '', $args);

        $query = "SELECT YEAR(post_date) AS `year`, MONTH(post_date) AS `month`, count(ID) as posts FROM $wpdb->posts $join $where GROUP BY YEAR(post_date), MONTH(post_date) ORDER BY post_date $order $limit";
        $key = md5($query);
        $cache = wp_cache_get('get_archives2', 'general');
        if (!!empty($cache[$key])) {
            $arcresults = $wpdb->get_results($query);
            $cache[$key] = $arcresults;
            wp_cache_set('get_archives2', $cache, 'general');
        } else {
            $arcresults = $cache[$key];
        }

        return $arcresults;
    }

    function build_html($args, $arcresults)
    {
        extract($args, EXTR_SKIP);

        if (!$arcresults)
            return '';

        $cur_year = -1;
        $afterafter = $after;

        $output = '<ul class="yearArchiveList">'; // (1)
        foreach ((array) $arcresults as $arcresult) {
            if ($cur_year != $arcresult->year) {
                if ($cur_year > 0) {
                    $output .= "</ul>"; // (/3)
                    $output .= "</li>\n"; // (/2)
                }
                $output .= '<li><span class="year">'  . $arcresult->year . "年</span>"; // (2)
                $output .= '<ul class="eachYear">'; // (3)

                $cur_year = $arcresult->year;
            }

            if ($show_post_count)
                $after = " ({$arcresult->posts}){$afterafter}";

            $output .= '<li class="singleList">' . $this->get_archives_link($arcresult->year, $arcresult->month, $before, $after) . "</li>\n";
        }
        $output .= "</ul>"; // (/3)
        $output .= "</li>\n"; // (/2)
        $output .= "</ul>\n"; // (/1)

        return $output;
    }

    function get_archives_link($year, $month, $before = '', $after = '')
    {
        global $wp_locale;

        $url = get_month_link($year, $month);
        $url = esc_url($url);

        $text = $wp_locale->get_month($month);
        $text = wptexturize($text);

        $title_text = sprintf(__('%1$s %2$d'), $wp_locale->get_month($month), $year);
        $title_text = esc_attr($title_text);

        $link_html = "$before<a href='$url' title='$title_text'>$text</a>$after";
        $link_html = apply_filters('get_archives2_link', $link_html);

        return $link_html;
    }
}

register_widget("Widget_Archives2");

//アーカイブの見出し
//--------------------------------------------------------------------
add_filter('get_the_archive_title', function ($title) {
    if (is_category()) {
        $title = single_cat_title('', false);
    } elseif (is_tag()) {
        $title = single_tag_title('', false);
    } elseif (is_tax()) {
        $title = single_term_title('', false);
    } elseif (is_post_type_archive()) {
        $title = post_type_archive_title('', false);
    } elseif (is_date()) {
        $title = get_the_time('Y年n月');
    } elseif (is_search()) {
        $title = '検索結果：' . esc_html(get_search_query(false));
    } elseif (is_404()) {
        $title = '「404」ページが見つかりません';
    } elseif (is_author()) {
        $title =  get_the_author();
    } else {
    }
    return $title;
});


//著者情報のSNS追加
//--------------------------------------------------------------------
function update_profile_fields($contactmethods)
{
    //項目の追加
    $contactmethods['facebook'] = 'Facebook';
    $contactmethods['twitter'] = 'Twitter';
    $contactmethods['instagram'] = 'Instagram';
    $contactmethods['youtube'] = 'YouTube';
    $contactmethods['contact_url'] = 'お問い合わせURL';

    return $contactmethods;
}
add_filter('user_contactmethods', 'update_profile_fields', 10, 1);

//追加した独自項目の更新
function update_user_profile_fields($user_id, $old_user_data)
{
    //テキストエリアを更新
    if (!empty($_POST['free_input'])) {
        update_user_meta($user_id, 'free_input', $_POST['free_input'], $old_user_data->t_area);
    }
}
add_action('profile_update', 'update_user_profile_fields', 10, 2);


//パンくずリスト
//--------------------------------------------------------------------
function breadcrumb()
{
    if (!is_front_page()) {
        $home = '<li class="breadcrumb-item"><a href="' . get_bloginfo('url') . '" class="breadcrumb-link">HOME</a></li>';

        echo '<div class="container"><ul class="breadcrumb-list">';
    }
    if (is_front_page()) {
        // トップページの場合
    } else if (is_home()) {
        echo $home;
        the_archive_title('<li class="breadcrumb-item">', '</li>');
    } else if (is_category()) {
        // カテゴリページの場合
        $cat = get_queried_object();
        $cat_id = $cat->parent;
        $cat_list = array();
        while ($cat_id != 0) {
            $cat = get_category($cat_id);
            $cat_link = get_category_link($cat_id);
            array_unshift($cat_list, '<li class="breadcrumb-item"><a href="' . $cat_link . '" class="breadcrumb-link">' . $cat->name . '</a></li>');
            $cat_id = $cat->parent;
        }
        echo $home;
        foreach ($cat_list as $value) {
            echo $value;
        }
        the_archive_title('<li class="breadcrumb-item">', '</li>');
    } else if (is_archive()) {
        // 月別アーカイブ・タグページの場合
        echo $home;
        the_archive_title('<li class="breadcrumb-item">', '</li>');
    } else if (is_single()) {
        // 投稿ページの場合
        $cat = get_the_category();
        if (!empty($cat[0]->cat_ID)) $cat_id = $cat[0]->cat_ID;
        $cat_list = array();
        while ($cat_id != 0) {
            $cat = get_category($cat_id);
            $cat_link = get_category_link($cat_id);
            array_unshift($cat_list, '<li class="breadcrumb-item"><a href="' . $cat_link . '" class="breadcrumb-link">' . $cat->name . '</a></li>');
            $cat_id = $cat->parent;
        }
        foreach ($cat_list as $value) {
            echo $value;
        }
        the_title('<li class="breadcrumb-item">', '</li>');
    } else if (is_page()) {
        // 固定ページの場合
        echo $home;
        the_title('<li class="breadcrumb-item">', '</li>');
    } else if (is_search()) {
        // 検索ページの場合
        echo $home;
        echo '<li class="breadcrumb-item">「' . get_search_query() . '」の検索結果</li>';
    } else if (is_404()) {
        // 404ページの場合
        echo $home;
        echo '<li class="breadcrumb-item">ページが見つかりません</li>';
    }
    if (!is_front_page()) {
        echo "</ul></div>";
    }
}

// アーカイブの余計なタイトルを削除
add_filter('get_the_archive_title', function ($title) {
    if (is_category()) {
        $title = single_cat_title('', false);
    } elseif (is_tag()) {
        $title = single_tag_title('', false);
    } elseif (is_month()) {
        $title = single_month_title('', false);
    }
    return $title;
});
